==> gridstack-8.x-2.9.tar.gz: gridstack/src/Plugin/Field/FieldFormatter/GridStackFileFormatterBase.php <==
<?php

namespace Drupal\gridstack\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\blazy\Plugin\Field\FieldFormatter\BlazyFileFormatterBase;
use Drupal\gridstack\GridStackDefault;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for gridstack image and file ER formatters.
 */
abstract class GridStackFileFormatterBase extends BlazyFileFormatterBase {

  use GridStackFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    return self::injectServices($instance, $container, 'image');
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return GridStackDefault::imageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $entities = $this->getEntitiesToView($items, $langcode);

    // Early opt-out if the field is empty.
    if (empty($entities)) {
      return [];
    }

    return $this->commonViewElements($items, $langcode, $entities);
  }

  /**
   * Build the gridstack carousel elements.
   */
  public function buildElements(array &$build, $files) {
    $settings = &$build['settings'];
    $blazies  = $settings['blazies'];
    $item_id  = $blazies->get('item.id');
    $elements = $this->getElements($build, $files, 'caption');

    foreach ($elements as $delta => $element) {
      $captions = $element['caption'] ?? [];

      // Do not pass captions to theme_blazy().
      unset($element['caption']);

      // Image with responsive image, lazyLoad, and lightbox supports.
      $element[$item_id] = $this->formatter->getBlazy($element, $delta);

      // Build captions if so configured.
      $element['caption'] = $captions;

      // Build individual gridstack item.
      $build['items'][] = $element;
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getPluginScopes(): array {
    return [
      'background'       => TRUE,
      'no_ratio'         => TRUE,
      'responsive_image' => TRUE,
    ] + parent::getPluginScopes();
  }

}

==> gridstack-8.x-2.10.tar.gz: gridstack/src/Plugin/Field/FieldFormatter/GridStackFileFormatterBase.php <==
<?php

namespace Drupal\gridstack\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\blazy\Plugin\Field\FieldFormatter\BlazyFileFormatterBase;
use Drupal\gridstack\GridStackDefault;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for gridstack image and file ER formatters.
 */
abstract class GridStackFileFormatterBase extends BlazyFileFormatterBase {

  use GridStackFormatterTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    return self::injectServices($instance, $container, 'image');
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return GridStackDefault::imageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $entities = $this->getEntitiesToView($items, $langcode);

    // Early opt-out if the field is empty.
    if (empty($entities)) {
      return [];
    }

    return $this->commonViewElements($items, $langcode, $entities);
  }

  /**
   * Build the gridstack carousel elements.
   */
  public function buildElements(array &$build, $files, $langcode) {
    $settings = &$build['settings'];
    $blazies  = $settings['blazies'];
    $item_id  = $blazies->get('item.id');
    $elements = $this->getElements($build, $files, 'caption');

    foreach ($elements as $delta => $element) {
      $captions = $element['caption'] ?? [];

      // Do not pass captions to theme_blazy().
      unset($element['caption']);

      // Image with responsive image, lazyLoad, and lightbox supports.
      $element[$item_id] = $this->formatter->getBlazy($element, $delta);

      // Build captions if so configured.
      $element['caption'] = $captions;

      // Build individual gridstack item.
      $build['items'][] = $element;
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function getPluginScopes(): array {
    return [
      'background'       => TRUE,
      'no_ratio'         => TRUE,
      'responsive_image' => TRUE,
    ] + parent::getPluginScopes();
  }

}
